Trade
=====

.. autoclass:: algotradepy.trade.Trade
    :members:
    :undoc-members:

.. autoclass:: algotradepy.trade.TradeStatus
    :members:
    :undoc-members:

.. autoclass:: algotradepy.trade.TradeState
    :members:
